@@ -552,18 +552,6 @@ function decodeCall(call) {
   }
 }
 
-// lib/assertions/providers/lambda-handler/results.ts
-var ResultsCollectionHandler = class extends CustomResourceHandler {
-  async processEvent(request2) {
-    const reduced = request2.assertionResults.reduce((agg, result, idx) => {
-      const msg = result.status === "pass" ? "pass" : `fail - ${result.message}`;
-      return `${agg}
-Test${idx}: ${msg}`;
-    }, "").trim();
-    return { message: reduced };
-  }
-};
-
 // lib/assertions/providers/lambda-handler/utils.ts
 function decode(object) {
   return JSON.parse(JSON.stringify(object), (_k, v) => {
@@ -605,7 +593,6 @@ var AwsApiCallHandler = class extends CustomResourceHandler {
 
 // lib/assertions/providers/lambda-handler/types.ts
 var ASSERT_RESOURCE_TYPE = "Custom::DeployAssert@AssertEquals";
-var RESULTS_RESOURCE_TYPE = "Custom::DeployAssert@ResultsCollection";
 var SDK_RESOURCE_TYPE_PREFIX = "Custom::DeployAssert@SdkCall";
 
 // lib/assertions/providers/lambda-handler/index.ts
@@ -620,8 +607,6 @@ function createResourceHandler(event, context) {
   switch (event.ResourceType) {
     case ASSERT_RESOURCE_TYPE:
       return new AssertionHandler(event, context);
-    case RESULTS_RESOURCE_TYPE:
-      return new ResultsCollectionHandler(event, context);
     default:
       throw new Error(`Unsupported resource type "${event.ResourceType}`);
   }
